@@ -3,9 +3,13 @@
 #[macro_use]
 pub mod util;
 
+#[macro_use]
+pub mod test_util;
+
 pub mod bed_refinery;
 pub mod linear_track_mixture;
 pub mod refined_bed_zipper;
+pub mod top_k;
 pub mod track_correlation;
 pub mod track_histogram;
 pub mod track_zipper;
